/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.util.Optional;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GeometryType;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.Lod;
import de.hft.stuttgart.quality.model.AllPolygonsWrongOrientation;
import de.hft.stuttgart.quality.model.ValidationError;

public class AllPolygonsWrongOrientationErrorTest {

	@Test
	public void testAddToValidationResult() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD2);
		GmlId gmlId = new GmlId("testId");
		geom.setGmlId(gmlId);
		AllPolygonsWrongOrientationError err = new AllPolygonsWrongOrientationError(geom);
		Optional<ValidationError> ade = err.convertToQualityAdeDatastructure();
		assertNotNull(ade);
		assertTrue(ade.isPresent());
		ValidationError validationError = ade.get();
		assertTrue(validationError instanceof AllPolygonsWrongOrientation);
		AllPolygonsWrongOrientation adeErr = (AllPolygonsWrongOrientation) validationError;
		String geometryId = adeErr.getGeometryId();
		assertEquals(gmlId.getGmlString(), geometryId);
	}

}
